instancelib.feature\_extraction.doc2vec module
==============================================

.. automodule:: instancelib.feature_extraction.doc2vec
   :members:
   :undoc-members:
   :show-inheritance:
